let
  # Folders
  steam = import ./modules/steam;
  services = import ./modules/services;
  # Files
  accounts = import ./modules/accounts.nix;
  android = import ./modules/android.nix;
  audio = import ./modules/audio.nix;
  bluetooth = import ./modules/bluetooth.nix;
  corectrl = import ./modules/corectrl.nix;
  dconf = import ./modules/dconf.nix;
  disks = import ./modules/disks.nix;
  doas = import ./modules/doas.nix;
  environment = import ./modules/environment.nix;
  firejail = import ./modules/firejail.nix;
  fonts = import ./modules/fonts.nix;
  gnome = import ./modules/gnome.nix;
  greetd = import ./modules/greetd.nix;
  gvfs = import ./modules/gvfs.nix;
  home-manager = import ./modules/home-manager.nix;
  locale = import ./modules/locale.nix;
  network = import ./modules/network.nix;
  nix = import ./modules/nix.nix;
  ollama-main = import ./modules/ollama-main.nix;
  plasma = import ./modules/plasma.nix;
  printing = import ./modules/printing.nix;
  regreet = import ./modules/regreet.nix;
  syncthing = import ./modules/syncthing.nix;
  sysstat = import ./modules/sysstat.nix;
  system = import ./modules/system.nix;
  virtualization = import ./modules/virtualization.nix;
  xserver = import ./modules/xserver.nix;
in {
  flake = {
    nixosModules = {
      inherit
        accounts
        android
        audio
        bluetooth
        corectrl
        dconf
        disks
        doas
        environment
        firejail
        fonts
        gnome
        greetd
        gvfs
        home-manager
        locale
        network
        nix
        ollama-main
        plasma
        printing
        regreet
        services
        steam
        syncthing
        sysstat
        system
        virtualization
        xserver
        ;
      personal = {
        imports = [
          android
          audio
          bluetooth
          corectrl
          dconf
          disks
          firejail
          fonts
          plasma
          printing
          steam
          sysstat
          virtualization
        ];
      };
      desktop = {
        imports = [
          syncthing
          ollama-main
        ];
      };
      server = {
        imports = [
          services
        ];
      };
      shared = {
        imports = [
          accounts
          doas
          environment
          gvfs
          home-manager
          locale
          nix
          system
          xserver
        ];
      };
    };
  };
}
